@@ -14,7 +14,7 @@
                  "\n  Run again with 'localHub=FALSE'")
         }else if (cnt > 1){
             stop("Corrupt Cache: sqlite file",
-                 "\n  See vignette section on corrupt cache",
+                 "\n  See AnnotationHub's TroubleshootingTheHubs vignette section on corrupt cache",
                  "\n  cache: ", bfccache(bfc),
                  "\n  filename: ",
                  paste0(tolower(.class), ".sqlite3"),
@@ -33,7 +33,7 @@
                               fpath=remote_db, proxy=proxy)
         } else if (cnt > 1){
             stop("Corrupt Cache: sqlite file",
-                 "\n  See vignette section on corrupt cache",
+                 "\n  See AnnotationHub's TroubleshootingTheHubs vignette section on corrupt cache",
                  "\n  cache: ", bfccache(bfc),
                  "\n  filename: ",
                  paste0(tolower(.class), ".sqlite3"),
@@ -79,7 +79,7 @@
             warning("empty 'resources' table; database may be corrupt")
     }, error=function(err) {
         stop("Corrupt Hub Database",
-             "\n  See vignette section on corrupt database",
+             "\n  See AnnotationHub's TroubleshootingTheHubs vignette section on corrupt database",
              "\n  database: ", sQuote(path),
              "\n  reason: ", conditionMessage(err),
              call.=FALSE)
@@ -136,7 +136,7 @@ refreshHub <- function(..., hub, cache, proxy,
                           fpath=remote_db, proxy=proxy)
     } else if (cnt > 1){
         stop("Corrupt Cache: sqlite file",
-             "\n  See vignette section on corrupt cache",
+             "\n  See AnnotationHub's TroubleshootingTheHubs vignette section on corrupt cache",
              "\n  cache: ", bfccache(bfc),
              "\n  filename: ",
              paste0(tolower(.class), ".sqlite3"),
@@ -255,7 +255,7 @@ possibleDates <- function(x) {
             stop("Corrupt Cache: resource id",
                  "\n  More than one entry in cache for: ",
                  rnames,
-                 "\n  See vignette section on corrupt cache", call.=FALSE)
+                 "\n  See AnnotationHub's TroubleshootingTheHubs vignette section on corrupt cache", call.=FALSE)
         } else if (cnt == 0){
             bfcadd(bfc, rname=rnames, fpath=hubpath, proxy=proxy)
         } else {
@@ -308,11 +308,28 @@ possibleDates <- function(x) {
         fls <-  cache(getHub(class), force=force, verbose=verbose)
         .get1(class)
     }, error=function(err) {
-        stop("failed to load resource",
-             "\n  name: ", names(x),
-             "\n  title: ", x$title,
-             "\n  reason: ", conditionMessage(err),
-             call.=FALSE)
+
+        if (!isLocalHub(getHub(class))){
+            tryCatch({
+                message("Error loading resource.",
+                        "\n attempting to re-download")
+                fls <-  cache(getHub(class), force=TRUE, verbose=verbose)
+                .get1(class)
+            }, error = function(err){
+                stop("failed to load resource",
+                     "\n  name: ", names(x),
+                     "\n  title: ", x$title,
+                     "\n  reason: ", conditionMessage(err),
+                     call.=FALSE)
+            })
+        } else {
+            stop("failed to load resource",
+                 "\n  name: ", names(x),
+                 "\n  title: ", x$title,
+                 "\n  reason: ", conditionMessage(err),
+                 "Consider rerunning with localHub=FALSE",
+                 call.=FALSE)
+        }
     })
 }
 
