@@ -3,7 +3,7 @@ options(width=100)
 suppressPackageStartupMessages({
     ## load here to avoid noise in the body of the vignette
     library(AnnotationHub)
-    library(GenomicFeatures)
+    library(txdbmaker)
     library(Rsamtools)
     library(VariantAnnotation)
 })
@@ -16,10 +16,11 @@ query(ah, "OrgDb")
 orgdb <- query(ah, c("OrgDb", "maintainer@bioconductor.org"))[[1]]
 
 ## ----less-model-org-select------------------------------------------------------------------------
-keytypes(orgdb)
-columns(orgdb)
+library(AnnotationDbi)
+AnnotationDbi::keytypes(orgdb)
+AnnotationDbi::columns(orgdb)
 egid <- head(keys(orgdb, "ENTREZID"))
-select(orgdb, egid, c("SYMBOL", "GENENAME"), "ENTREZID")
+AnnotationDbi::select(orgdb, egid, c("SYMBOL", "GENENAME"), "ENTREZID")
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------
 #  url <- "http://egg2.wustl.edu/roadmap/data/byFileType/peaks/consolidated/broadPeak/E001-H3K4me1.broadPeak.gz"
@@ -99,7 +100,7 @@ keep <- names(tail(sort(seqlengths(dna)), 25))
 gtf_subset <- gtf[seqnames(gtf) %in% keep]
 
 ## ----takifugu-txdb--------------------------------------------------------------------------------
-library(GenomicFeatures)         # for makeTxDbFromGRanges
+library(txdbmaker)         # for makeTxDbFromGRanges
 txdb <- makeTxDbFromGRanges(gtf_subset)
 
 ## ----takifugu-exons-------------------------------------------------------------------------------
