@@ -33,8 +33,11 @@ length(ah)
 ahs <- query(ah, c('inparanoid8', 'ailuropoda'))
 ahs
 
-## ----display, eval=FALSE--------------------------------------------------------------------------
-#  d <- display(ah)
+## ----BiocHubsShiny, eval=FALSE--------------------------------------------------------------------
+#  BiocHubsShiny::BiocHubsShiny()
+
+## ----echo=FALSE,fig.cap="BiocHubsShiny query with terms dataprovider = 'inparanoid' and species = 'ailuropoda'"----
+knitr::include_graphics("ailMel1_BiocHubsShiny.png")
 
 ## ----dm2------------------------------------------------------------------------------------------
 dm
